@@ -1,13 +1,11 @@
 from copy import deepcopy
 from typing import Any, Dict, List
 
-import logging
 import requests
 
 from obsei.sink.base_sink import BaseSink, BaseSinkConfig, Convertor
 from obsei.analyzer.base_analyzer import AnalyzerResponse
 
-logger = logging.getLogger(__name__)
 
 DEFAULT_HEADERS = {
     "Content-type": "application/json"
@@ -42,7 +40,7 @@ class HttpSink(BaseSink):
         for analyzer_response in analyzer_responses:
             payloads.append(self.convertor.convert(
                 analyzer_response=analyzer_response,
-                base_payload=deepcopy(config.base_payload)
+                base_payload=dict() if config.base_payload is None else deepcopy(config.base_payload)
             ))
 
         for payload in payloads:
@@ -51,8 +49,6 @@ class HttpSink(BaseSink):
                 json=payload,
                 headers=headers,
             )
-
-            logger.info(f"response='{response.__dict__}'")
             responses.append(response)
 
         return responses
